@@ -4,7 +4,13 @@ from django.utils.timezone import now
 import factory
 from django_libs.tests.factories import SimpleTranslationMixin
 
-from ..models import Event, EventCategory, EventCategoryTitle, EventTitle
+from ..models import (
+    Event,
+    EventCategory,
+    EventCategoryTitle,
+    EventTitle,
+    EventPluginModel,
+)
 
 
 class EventCategoryFactory(SimpleTranslationMixin, factory.Factory):
@@ -43,6 +49,13 @@ class EventFactory(SimpleTranslationMixin, BaseEventFactory):
         return (EventTitleFactory, 'event')
 
 
+class EventPluginModelFactory(factory.Factory):
+    """Factory for ``EventPluginModel`` objects."""
+    FACTORY_FOR = EventPluginModel
+
+    event = factory.SubFactory(EventFactory)
+
+
 class EventTitleFactory(factory.Factory):
     """Factory for the ``EventTitle`` model."""
     FACTORY_FOR = EventTitle
